:
# NAME:
#	finfo.sh - file info
#
# SYNOPSIS:
#	. finfo.sh
#	eval `file_info [-m] "file" "prefix"`
#
# DESCRIPTION:
#	This routine is from configs(8) and sets a bunch of variables
#	called ${prefix}_* describing "file".  If the '-m' option is
#	given then the file mode is converted to octal.  The default
#	"prefix" is 'file' so
#.nf
#
#		finfo.sh -m finfo.sh
#
#	might give:
#
#		file_inum=425597
#		file_mode=0775
#		file_type=file
#		file_links=1
#		file_owner=sjg
#		file_group=wheel
#		file_bytes=2776
#
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: finfo.sh,v 1.2 2001/08/30 08:07:29 sjg Exp $
#
#	@(#)Copyright (c) 1998 Simon J. Gerraty. All rights reserved.
#	
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to use, modify and distribute this source code 
#	is granted subject to the following conditions.
#	1/ that the above copyright notice and this notice 
#	are preserved in all copies and that due credit be given 
#	to the author.	
#	2/ that any changes to this code are clearly commented 
#	as such so that the author does not get blamed for bugs 
#	other than his own.
#	3/ If there is an accompanying License file its provisions
#	must also be met.
#	
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

file_info() {
	(
        case "$1" in
	-m) shift; _mode=octal;;
	*) _mode=raw;;
	esac
	file=$1
	prefix=${2:-file}
	set -- `${FIND:-find} $file -ls -prune 2>/dev/null`
	echo ${prefix}_inum=$1
	case "$3" in
	d*)	type=directory;;
	l*)	type=symlink
		(
			shift 9; eval v='$'$#
			case "$v" in
			"->"|"")# Solaris at least has buggy find(1)
				set -- `"ls" -l $file`
				shift 6; eval v='$'$#
				;;
			esac
			echo ${prefix}_val=$v
		)
		;;
	c*)	type=char_device;;
	b*)	type=block_device;;
	p*)	type=fifo;;
	*)	type=file;;
	esac
        case $_mode in
	octal)	# trust me
                echo ${prefix}_mode=`echo $3 | sed -e 's/.\(...\)\(...\)\(...\)/\1 \2 \3/' -e 's/s/xs/g' -e 's/t/xt/g' -e 's/S/-s/g' -e 's/---/0/g' -e 's/--x/1/g' -e 's/-w-/2/g' -e 's/r--/4/g' -e 's/r-x/5/g' -e 's/rw-/6/g' -e 's/rwx/7/g' -e 's/^\(.\)s \(.\)s \(.\)/6\1\2\3/' -e 's/^\(.\)s \(.\) \(.\)/4\1\2\3/' -e 's/^\(.\) \(.\)s \(.\)/2\1\2\3/' -e 's/^\(.\) \(.\) \(.\)t/1\1\2\3/' -e 's/^\(.\) \(.\)s \(.\)t/3\1\2\3/' -e 's/^\(.\)s \(.\) \(.\)t/5\1\2\3/' -e 's/^\(.\)s \(.\)s \(.\)t/7\1\2\3/' -e 's/^/0/' -e 's/ //g'`
                ;;
	*)
                echo ${prefix}_mode=$3
                ;;
	esac
	echo ${prefix}_type=$type
	echo ${prefix}_links=$4
	echo ${prefix}_owner=$5
	echo ${prefix}_group=$6
	case "$3" in
	[cb]*)
		set -- `IFS=,; echo $7 $8`
		echo ${prefix}_bytes=0
		echo ${prefix}_major=$1
		echo ${prefix}_minor=$2
		;;
	*)
		echo ${prefix}_bytes=$7
		;;
	esac
	)
}

case ./$0 in
*/finfo*) file_info "$@";;
esac
